==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/LimitRangeItemBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class LimitRangeItemBuilder extends LimitRangeItemFluentImpl<LimitRangeItemBuilder> implements VisitableBuilder<LimitRangeItem,LimitRangeItemBuilder>{

     LimitRangeItemFluent<?> fluent;
public LimitRangeItemBuilder(){
    this(new LimitRangeItem());
}
public LimitRangeItemBuilder( LimitRangeItemFluent<?> fluent ){
    this(fluent, new LimitRangeItem());
}
public LimitRangeItemBuilder( LimitRangeItemFluent<?> fluent , LimitRangeItem instance ){
    this.fluent = fluent; fluent.withDefault(instance.getDefault()); fluent.withDefaultRequest(instance.getDefaultRequest()); fluent.withMax(instance.getMax()); fluent.withMaxLimitRequestRatio(instance.getMaxLimitRequestRatio()); fluent.withMin(instance.getMin()); fluent.withType(instance.getType()); 
}
public LimitRangeItemBuilder( LimitRangeItem instance ){
    this.fluent = this; this.withDefault(instance.getDefault()); this.withDefaultRequest(instance.getDefaultRequest()); this.withMax(instance.getMax()); this.withMaxLimitRequestRatio(instance.getMaxLimitRequestRatio()); this.withMin(instance.getMin()); this.withType(instance.getType()); 
}

public LimitRangeItem build(){
    LimitRangeItem buildable = new LimitRangeItem(fluent.getDefault(),fluent.getDefaultRequest(),fluent.getMax(),fluent.getMaxLimitRequestRatio(),fluent.getMin(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
LimitRangeItemBuilder that = (LimitRangeItemBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/kubernetes/api/model/LimitRangeItemBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class LimitRangeItemBuilder extends LimitRangeItemFluentImpl<LimitRangeItemBuilder> implements VisitableBuilder<LimitRangeItem,LimitRangeItemBuilder>{

     LimitRangeItemFluent<?> fluent;
public LimitRangeItemBuilder(){
    this(new LimitRangeItem());
}
public LimitRangeItemBuilder( LimitRangeItemFluent<?> fluent ){
    this(fluent, new LimitRangeItem());
}
public LimitRangeItemBuilder( LimitRangeItemFluent<?> fluent , LimitRangeItem instance ){
    this.fluent = fluent; fluent.withDefault(instance.getDefault()); fluent.withDefaultRequest(instance.getDefaultRequest()); fluent.withMax(instance.getMax()); fluent.withMaxLimitRequestRatio(instance.getMaxLimitRequestRatio()); fluent.withMin(instance.getMin()); fluent.withType(instance.getType()); 
}
public LimitRangeItemBuilder( LimitRangeItem instance ){
    this.fluent = this; this.withDefault(instance.getDefault()); this.withDefaultRequest(instance.getDefaultRequest()); this.withMax(instance.getMax()); this.withMaxLimitRequestRatio(instance.getMaxLimitRequestRatio()); this.withMin(instance.getMin()); this.withType(instance.getType()); 
}

public LimitRangeItem build(){
    LimitRangeItem buildable = new LimitRangeItem(fluent.getDefault(),fluent.getDefaultRequest(),fluent.getMax(),fluent.getMaxLimitRequestRatio(),fluent.getMin(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
LimitRangeItemBuilder that = (LimitRangeItemBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
